# ویرایشگر فارسی پیشرفته برای جنگو

__version__ = '1.0.1'
__author__ = 'Persian Editor Team'
__email__ = 'persianeditor.ir@gmail.com'
__license__ = 'MIT'

default_app_config = 'persian_editor.apps.PersianEditorConfig'
